@@ -1,4 +1,4 @@
-# Copyright 2021 DeepL GmbH (https://www.deepl.com)
+# Copyright 2022 DeepL SE (https://www.deepl.com)
 # Use of this source code is governed by an MIT
 # license that can be found in the LICENSE file.
 
@@ -54,3 +54,9 @@ class GlossaryNotFoundException(DeepLException):
     """The specified glossary was not found."""
 
     pass
+
+
+class DocumentNotReadyException(DeepLException):
+    """The translation of the specified document is not yet complete."""
+
+    pass
