@@ -1,9 +1,10 @@
-# Copyright 2021 DeepL GmbH (https://www.deepl.com)
+# Copyright 2022 DeepL SE (https://www.deepl.com)
 # Use of this source code is governed by an MIT
 # license that can be found in the LICENSE file.
 
 from . import http_client, util
 from .exceptions import (
+    DocumentNotReadyException,
     GlossaryNotFoundException,
     QuotaExceededException,
     TooManyRequestsException,
@@ -226,7 +227,8 @@ class Usage:
 
         @property
         def valid(self) -> bool:
-            """True iff both the count and limit are set for this usage type."""
+            """True iff both the count and limit are set for this usage
+            type."""
             return self._count is not None and self._limit is not None
 
         @property
@@ -494,6 +496,7 @@ class Translator:
         content: str,
         json: Optional[dict],
         glossary: bool = False,
+        downloading_document: bool = False,
     ):
         message = ""
         if json is not None and "message" in json:
@@ -522,6 +525,11 @@ class Translator:
                 "Too many requests, DeepL servers are currently experiencing "
                 f"high load{message}"
             )
+        elif status_code == http.HTTPStatus.SERVICE_UNAVAILABLE:
+            if downloading_document:
+                raise DocumentNotReadyException(f"Document not ready{message}")
+            else:
+                raise DeepLException(f"Service unavailable{message}")
         else:
             status_name = (
                 http.client.responses[status_code]
@@ -539,11 +547,13 @@ class Translator:
         """Internal function to check given languages are valid."""
         if target_lang == "EN":
             raise DeepLException(
-                'target_lang="EN" is deprecated, please use "EN-GB" or "EN-US" instead.'
+                'target_lang="EN" is deprecated, please use "EN-GB" or "EN-US"'
+                "instead."
             )
         elif target_lang == "PT":
             raise DeepLException(
-                'target_lang="PT" is deprecated, please use "PT-PT" or "PT-BR" instead.'
+                'target_lang="PT" is deprecated, please use "PT-PT" or "PT-BR"'
+                "instead."
             )
 
     def _check_language_and_formality(
@@ -751,17 +761,19 @@ class Translator:
 
         :param input_path: Path to document to be translated.
         :param output_path: Path to store translated document.
-        :param source_lang: (Optional) Language code of input document, for example "DE",
-            "EN", "FR". If omitted, DeepL will auto-detect the input language.
-        :param target_lang: Language code to translate document into, for example "DE",
-            "EN-US", "FR".
-        :param formality: (Optional) Desired formality for translation, as Formality
-            enum, "less" or "more".
+        :param source_lang: (Optional) Language code of input document, for
+            example "DE", "EN", "FR". If omitted, DeepL will auto-detect the
+            input language.
+        :param target_lang: Language code to translate document into, for
+            example "DE", "EN-US", "FR".
+        :param formality: (Optional) Desired formality for translation, as
+            Formality enum, "less" or "more".
         :param glossary: (Optional) glossary or glossary ID to use for
             translation. Must match specified source_lang and target_lang.
 
-        :raises DocumentTranslationException: If an error occurs during translation,
-            The exception includes information about the document request.
+        :raises DocumentTranslationException: If an error occurs during
+            translation. The exception includes information about the document
+            request.
         """
         with open(input_path, "rb") as in_file:
             with open(output_path, "wb") as out_file:
@@ -794,7 +806,8 @@ class Translator:
 
         :param input_document: Document to translate as a file-like object. It
             is recommended to open files in binary mode.
-        :param output_document: File-like object to receive translated document.
+        :param output_document: File-like object to receive translated
+            document.
         :param source_lang: (Optional) Language code of input document, for
             example "DE", "EN", "FR". If omitted, DeepL will auto-detect the
             input language.
@@ -847,6 +860,7 @@ class Translator:
         target_lang: str,
         formality: Union[str, Formality] = Formality.DEFAULT,
         glossary: Union[str, GlossaryInfo, None] = None,
+        filename: Optional[str] = None,
     ) -> DocumentHandle:
         """Upload document to be translated and return handle associated with
         request.
@@ -862,6 +876,8 @@ class Translator:
             Formality enum, "less" or "more".
         :param glossary: (Optional) glossary or glossary ID to use for
             translation. Must match specified source_lang and target_lang.
+        :param filename: (Optional) Filename including extension, only required
+            if uploading string or bytes containing file content.
         :return: DocumentHandle with ID and key identifying document.
         """
 
@@ -869,7 +885,15 @@ class Translator:
             source_lang, target_lang, formality, glossary
         )
 
-        files = {"file": input_document}
+        if isinstance(input_document, (str, bytes)):
+            if filename is None:
+                raise ValueError(
+                    "filename is required if uploading file content as string "
+                    "or bytes"
+                )
+            files = {"file": (filename, input_document)}
+        else:
+            files = {"file": input_document}
         status, content, json = self._api_call(
             "v2/document", data=request_data, files=files
         )
@@ -928,9 +952,9 @@ class Translator:
             url, data=data, stream=True
         )
 
-        if status_code == http.HTTPStatus.SERVICE_UNAVAILABLE:
-            raise DeepLException("Document not ready for download")
-        self._raise_for_status(status_code, "<file>", json)
+        self._raise_for_status(
+            status_code, "<file>", json, downloading_document=True
+        )
 
         if output_file:
             for chunk in response.iter_content(chunk_size=chunk_size):
